import 'package:appcheck/appcheck.dart';
import 'package:flutter_health_connect/flutter_health_connect.dart';
import 'package:health/health.dart';
import 'package:url_launcher/url_launcher.dart';

import 'package:vivanta_connect_flutter/helpers/helpers.dart';

const package = "com.google.android.apps.healthdata";
const googleFit = "com.google.android.apps.fitness";

class GoogleHealthConnect {
  HealthFactory health = HealthFactory(useHealthConnectIfAvailable: true);

  Future<void> install() async {
    await launchUrl(
      Uri.parse("market://details?id=$package"),
      mode: LaunchMode.externalApplication,
    );
  }

  Future<void> installGoogleFit() async {
    await launchUrl(
      Uri.parse("market://details?id=$googleFit"),
      mode: LaunchMode.externalApplication,
    );
  }

  Future<bool> isInstalled() async {
    return AppCheck.isAppEnabled(package);
  }

  Future<bool> isGoogleFitInstalled() async {
    return AppCheck.isAppEnabled(package);
  }

  Future<void> open() async {
    await HealthConnectFactory.openHealthConnectSettings();
  }

  Future<bool> requestAuthorization(
      List<HealthPermission> healthPermissions) async {
    final types =
        healthPermissions.map<HealthDataType>((e) => e.healthDataType).toList();
    final permissions = healthPermissions
        .map<HealthDataAccess>((e) => e.healthDataAccess)
        .toList();
    return health.requestAuthorization(types, permissions: permissions);
  }

  Future<bool> authorizationStatus(HealthDataType dataType) async {
    return health.isDataTypeAvailable(dataType);
  }

  Future<List<HealthDataPoint>> getDataPoint(
    List<HealthDataType> types,
    DateTime start,
    DateTime end,
  ) async {
    List<HealthDataPoint> healthData = await health.getHealthDataFromTypes(
      start,
      end,
      types,
    );

    return healthData;
  }
}
